@@ -1,4 +1,5 @@
-"""MySQLdb - A DB API v2.0 compatible interface to MySQL.
+"""
+MySQLdb - A DB API v2.0 compatible interface to MySQL.
 
 This package is a wrapper around _mysql, which mostly implements the
 MySQL C API.
@@ -10,13 +11,11 @@ on other items.
 
 For information on how MySQLdb handles type conversion, see the
 MySQLdb.converters module.
-
 """
 
-__revision__ = """$Revision$"""[11:-2]
 from MySQLdb.release import __version__, version_info, __author__
 
-import _mysql
+from . import _mysql
 
 if version_info != _mysql.version_info:
     raise ImportError("this is MySQLdb version %s, but _mysql is version %r" %
@@ -26,7 +25,7 @@ threadsafety = 1
 apilevel = "2.0"
 paramstyle = "format"
 
-from _mysql import *
+from ._mysql import *
 from MySQLdb.compat import PY2
 from MySQLdb.constants import FIELD_TYPE
 from MySQLdb.times import Date, Time, Timestamp, \
@@ -38,7 +37,6 @@ except NameError:
     from sets import ImmutableSet as frozenset
 
 class DBAPISet(frozenset):
-
     """A special type of set for which A == x is true if A is a
     DBAPISet and x is a member of that set."""
 
@@ -54,8 +52,8 @@ BINARY    = DBAPISet([FIELD_TYPE.BLOB, FIELD_TYPE.LONG_BLOB,
                      FIELD_TYPE.MEDIUM_BLOB, FIELD_TYPE.TINY_BLOB])
 NUMBER    = DBAPISet([FIELD_TYPE.DECIMAL, FIELD_TYPE.DOUBLE, FIELD_TYPE.FLOAT,
                      FIELD_TYPE.INT24, FIELD_TYPE.LONG, FIELD_TYPE.LONGLONG,
-                     FIELD_TYPE.TINY, FIELD_TYPE.YEAR])
-DATE      = DBAPISet([FIELD_TYPE.DATE, FIELD_TYPE.NEWDATE])
+                     FIELD_TYPE.TINY, FIELD_TYPE.YEAR, FIELD_TYPE.NEWDECIMAL])
+DATE      = DBAPISet([FIELD_TYPE.DATE])
 TIME      = DBAPISet([FIELD_TYPE.TIME])
 TIMESTAMP = DBAPISet([FIELD_TYPE.TIMESTAMP, FIELD_TYPE.DATETIME])
 DATETIME  = TIMESTAMP
@@ -91,13 +89,10 @@ __all__ = [ 'BINARY', 'Binary', 'Connect', 'Connection', 'DATE',
     'Date', 'Time', 'Timestamp', 'DateFromTicks', 'TimeFromTicks',
     'TimestampFromTicks', 'DataError', 'DatabaseError', 'Error',
     'FIELD_TYPE', 'IntegrityError', 'InterfaceError', 'InternalError',
-    'MySQLError', 'NULL', 'NUMBER', 'NotSupportedError', 'DBAPISet',
+    'MySQLError', 'NUMBER', 'NotSupportedError', 'DBAPISet',
     'OperationalError', 'ProgrammingError', 'ROWID', 'STRING', 'TIME',
     'TIMESTAMP', 'Warning', 'apilevel', 'connect', 'connections',
-    'constants', 'converters', 'cursors', 'debug', 'escape', 'escape_dict',
-    'escape_sequence', 'escape_string', 'get_client_info',
+    'constants', 'converters', 'cursors', 'debug', 'escape',
+    'escape_string', 'get_client_info',
     'paramstyle', 'string_literal', 'threadsafety', 'version_info']
 
-
-
-
