@@ -2,7 +2,6 @@
 
 These constants are error codes for the bulk of the error conditions
 that may occur.
-
 """
 
 if __name__ == "__main__":
@@ -35,8 +34,6 @@ if __name__ == "__main__":
 
 
 ERROR_FIRST = 1000
-HASHCHK = 1000
-NISAMCHK = 1001
 NO = 1002
 YES = 1003
 CANT_CREATE_FILE = 1004
@@ -44,27 +41,20 @@ CANT_CREATE_TABLE = 1005
 CANT_CREATE_DB = 1006
 DB_CREATE_EXISTS = 1007
 DB_DROP_EXISTS = 1008
-DB_DROP_DELETE = 1009
 DB_DROP_RMDIR = 1010
-CANT_DELETE_FILE = 1011
 CANT_FIND_SYSTEM_REC = 1012
 CANT_GET_STAT = 1013
-CANT_GET_WD = 1014
 CANT_LOCK = 1015
 CANT_OPEN_FILE = 1016
 FILE_NOT_FOUND = 1017
 CANT_READ_DIR = 1018
-CANT_SET_WD = 1019
 CHECKREAD = 1020
-DISK_FULL = 1021
 DUP_KEY = 1022
-ERROR_ON_CLOSE = 1023
 ERROR_ON_READ = 1024
 ERROR_ON_RENAME = 1025
 ERROR_ON_WRITE = 1026
 FILE_USED = 1027
 FILSORT_ABORT = 1028
-FORM_NOT_FOUND = 1029
 GET_ERRNO = 1030
 ILLEGAL_HA = 1031
 KEY_NOT_FOUND = 1032
@@ -74,7 +64,6 @@ OLD_KEYFILE = 1035
 OPEN_AS_READONLY = 1036
 OUTOFMEMORY = 1037
 OUT_OF_SORTMEMORY = 1038
-UNEXPECTED_EOF = 1039
 CON_COUNT_ERROR = 1040
 OUT_OF_RESOURCES = 1041
 BAD_HOST_ERROR = 1042
@@ -112,8 +101,6 @@ BLOB_USED_AS_KEY = 1073
 TOO_BIG_FIELDLENGTH = 1074
 WRONG_AUTO_KEY = 1075
 READY = 1076
-NORMAL_SHUTDOWN = 1077
-GOT_SIGNAL = 1078
 SHUTDOWN_COMPLETE = 1079
 FORCING_CLOSE = 1080
 IPSOCK_ERROR = 1081
@@ -128,7 +115,6 @@ WRONG_SUB_KEY = 1089
 CANT_REMOVE_ALL_FIELDS = 1090
 CANT_DROP_FIELD_OR_KEY = 1091
 INSERT_INFO = 1092
-INSERT_TABLE_USED = 1093
 UPDATE_TABLE_USED = 1093
 NO_SUCH_THREAD = 1094
 KILL_DENIED_ERROR = 1095
@@ -156,7 +142,7 @@ TOO_MANY_TABLES = 1116
 TOO_MANY_FIELDS = 1117
 TOO_BIG_ROWSIZE = 1118
 STACK_OVERRUN = 1119
-WRONG_OUTER_JOIN = 1120
+WRONG_OUTER_JOIN_UNUSED = 1120
 NULL_COLUMN_IN_INDEX = 1121
 CANT_FIND_UDF = 1122
 CANT_INITIALIZE_UDF = 1123
@@ -186,10 +172,6 @@ NO_SUCH_TABLE = 1146
 NONEXISTING_TABLE_GRANT = 1147
 NOT_ALLOWED_COMMAND = 1148
 SYNTAX_ERROR = 1149
-DELAYED_CANT_CHANGE_LOCK = 1150
-UNUSED1 = 1150
-TOO_MANY_DELAYED_THREADS = 1151
-UNUSED2 = 1151
 ABORTING_CONNECTION = 1152
 NET_PACKET_TOO_LARGE = 1153
 NET_READ_ERROR_FROM_PIPE = 1154
@@ -203,8 +185,6 @@ NET_WRITE_INTERRUPTED = 1161
 TOO_LONG_STRING = 1162
 TABLE_CANT_HANDLE_BLOB = 1163
 TABLE_CANT_HANDLE_AUTO_INCREMENT = 1164
-DELAYED_INSERT_TABLE_LOCKED = 1165
-UNUSED3 = 1165
 WRONG_COLUMN_NAME = 1166
 WRONG_KEY_COLUMN = 1167
 WRONG_MRG_TABLE = 1168
@@ -213,7 +193,6 @@ BLOB_KEY_WITHOUT_LENGTH = 1170
 PRIMARY_CANT_HAVE_NULL = 1171
 TOO_MANY_ROWS = 1172
 REQUIRES_PRIMARY_KEY = 1173
-NO_RAID_COMPILED = 1174
 UPDATE_WITHOUT_KEY_IN_SAFE_MODE = 1175
 KEY_DOES_NOT_EXITS = 1176
 CHECK_NO_SUCH_TABLE = 1177
@@ -222,11 +201,7 @@ CANT_DO_THIS_DURING_AN_TRANSACTION = 1179
 ERROR_DURING_COMMIT = 1180
 ERROR_DURING_ROLLBACK = 1181
 ERROR_DURING_FLUSH_LOGS = 1182
-ERROR_DURING_CHECKPOINT = 1183
 NEW_ABORTING_CONNECTION = 1184
-DUMP_NOT_IMPLEMENTED = 1185
-FLUSH_MASTER_BINLOG_CLOSED = 1186
-INDEX_REBUILD = 1187
 MASTER = 1188
 MASTER_NET_READ = 1189
 MASTER_NET_WRITE = 1190
@@ -237,7 +212,6 @@ CRASHED_ON_USAGE = 1194
 CRASHED_ON_REPAIR = 1195
 WARNING_NOT_COMPLETE_ROLLBACK = 1196
 TRANS_CACHE_FULL = 1197
-SLAVE_MUST_STOP = 1198
 SLAVE_NOT_RUNNING = 1199
 BAD_SLAVE = 1200
 MASTER_INFO = 1201
@@ -247,19 +221,14 @@ SET_CONSTANTS_ONLY = 1204
 LOCK_WAIT_TIMEOUT = 1205
 LOCK_TABLE_FULL = 1206
 READ_ONLY_TRANSACTION = 1207
-DROP_DB_WITH_READ_LOCK = 1208
-CREATE_DB_WITH_READ_LOCK = 1209
 WRONG_ARGUMENTS = 1210
 NO_PERMISSION_TO_CREATE_USER = 1211
-UNION_TABLES_IN_DIFFERENT_DIR = 1212
 LOCK_DEADLOCK = 1213
 TABLE_CANT_HANDLE_FT = 1214
-TABLE_CANT_HANDLE_FULLTEXT = 1214
 CANNOT_ADD_FOREIGN = 1215
 NO_REFERENCED_ROW = 1216
 ROW_IS_REFERENCED = 1217
 CONNECT_TO_MASTER = 1218
-QUERY_ON_MASTER = 1219
 ERROR_WHEN_EXECUTING_COMMAND = 1220
 WRONG_USAGE = 1221
 WRONG_NUMBER_OF_COLUMNS_IN_SELECT = 1222
@@ -285,7 +254,6 @@ OPERAND_COLUMNS = 1241
 SUBQUERY_NO_1_ROW = 1242
 UNKNOWN_STMT_HANDLER = 1243
 CORRUPT_HELP_DB = 1244
-CYCLIC_REFERENCE = 1245
 AUTO_CONVERT = 1246
 ILLEGAL_REFERENCE = 1247
 DERIVED_MUST_HAVE_ALIAS = 1248
@@ -294,8 +262,6 @@ TABLENAME_NOT_ALLOWED_HERE = 1250
 NOT_SUPPORTED_AUTH_MODE = 1251
 SPATIAL_CANT_HAVE_NULL = 1252
 COLLATION_CHARSET_MISMATCH = 1253
-SLAVE_WAS_RUNNING = 1254
-SLAVE_WAS_NOT_RUNNING = 1255
 TOO_BIG_FOR_UNCOMPRESS = 1256
 ZLIB_Z_MEM_ERROR = 1257
 ZLIB_Z_BUF_ERROR = 1258
@@ -308,7 +274,6 @@ WARN_DATA_OUT_OF_RANGE = 1264
 WARN_DATA_TRUNCATED = 1265
 WARN_USING_OTHER_HANDLER = 1266
 CANT_AGGREGATE_2COLLATIONS = 1267
-DROP_USER = 1268
 REVOKE_GRANTS = 1269
 CANT_AGGREGATE_3COLLATIONS = 1270
 CANT_AGGREGATE_NCOLLATIONS = 1271
@@ -322,7 +287,6 @@ MISSING_SKIP_SLAVE = 1278
 UNTIL_COND_IGNORED = 1279
 WRONG_NAME_FOR_INDEX = 1280
 WRONG_NAME_FOR_CATALOG = 1281
-WARN_QC_RESIZE = 1282
 BAD_FT_COLUMN = 1283
 UNKNOWN_KEY_CACHE = 1284
 WARN_HOSTNAME_WONT_WORK = 1285
@@ -333,7 +297,6 @@ FEATURE_DISABLED = 1289
 OPTION_PREVENTS_STATEMENT = 1290
 DUPLICATED_VALUE_IN_TYPE = 1291
 TRUNCATED_WRONG_VALUE = 1292
-TOO_MUCH_AUTO_TIMESTAMP_COLS = 1293
 INVALID_ON_UPDATE = 1294
 UNSUPPORTED_PS = 1295
 GET_ERRMSG = 1296
@@ -386,10 +349,8 @@ FPARSER_EOF_IN_COMMENT = 1342
 FPARSER_ERROR_IN_PARAMETER = 1343
 FPARSER_EOF_IN_UNKNOWN_PARAMETER = 1344
 VIEW_NO_EXPLAIN = 1345
-FRM_UNKNOWN_TYPE = 1346
 WRONG_OBJECT = 1347
 NONUPDATEABLE_COLUMN = 1348
-VIEW_SELECT_DERIVED = 1349
 VIEW_SELECT_CLAUSE = 1350
 VIEW_SELECT_VARIABLE = 1351
 VIEW_SELECT_TMPTABLE = 1352
@@ -398,7 +359,6 @@ WARN_VIEW_MERGE = 1354
 WARN_VIEW_WITHOUT_KEY = 1355
 VIEW_INVALID = 1356
 SP_NO_DROP_SP = 1357
-SP_GOTO_IN_HNDLR = 1358
 TRG_ALREADY_EXISTS = 1359
 TRG_DOES_NOT_EXIST = 1360
 TRG_ON_VIEW_OR_TEMP_TABLE = 1361
@@ -412,7 +372,6 @@ VIEW_NONUPD_CHECK = 1368
 VIEW_CHECK_FAILED = 1369
 PROCACCESS_DENIED_ERROR = 1370
 RELAY_LOG_FAIL = 1371
-PASSWD_LENGTH = 1372
 UNKNOWN_TARGET_BINLOG = 1373
 IO_ERR_LOG_INDEX_READ = 1374
 BINLOG_PURGE_PROHIBITED = 1375
@@ -423,13 +382,6 @@ LOG_PURGE_UNKNOWN_ERR = 1379
 RELAY_LOG_INIT = 1380
 NO_BINARY_LOGGING = 1381
 RESERVED_SYNTAX = 1382
-WSAS_FAILED = 1383
-DIFF_GROUPS_PROC = 1384
-NO_GROUP_FOR_PROC = 1385
-ORDER_WITH_PROC = 1386
-LOGGING_PROHIBIT_CHANGING_OF = 1387
-NO_FILE_MAPPING = 1388
-WRONG_MAGIC = 1389
 PS_MANY_PARAM = 1390
 KEY_PART_0 = 1391
 VIEW_CHECKSUM = 1392
@@ -457,10 +409,8 @@ SP_DUP_HANDLER = 1413
 SP_NOT_VAR_ARG = 1414
 SP_NO_RETSET = 1415
 CANT_CREATE_GEOMETRY_OBJECT = 1416
-FAILED_ROUTINE_BREAK_BINLOG = 1417
 BINLOG_UNSAFE_ROUTINE = 1418
 BINLOG_CREATE_ROUTINE_NEED_SUPER = 1419
-EXEC_STMT_WITH_OPEN_CURSOR = 1420
 STMT_HAS_NO_OPEN_CURSOR = 1421
 COMMIT_NOT_ALLOWED_IN_SF_OR_TRG = 1422
 NO_DEFAULT_FOR_VIEW_FIELD = 1423
@@ -474,7 +424,6 @@ QUERY_ON_FOREIGN_DATA_SOURCE = 1430
 FOREIGN_DATA_SOURCE_DOESNT_EXIST = 1431
 FOREIGN_DATA_STRING_INVALID_CANT_CREATE = 1432
 FOREIGN_DATA_STRING_INVALID = 1433
-CANT_CREATE_FEDERATED_TABLE = 1434
 TRG_IN_WRONG_SCHEMA = 1435
 STACK_OVERRUN_NEED_MORE = 1436
 TOO_LONG_BODY = 1437
@@ -486,7 +435,6 @@ CANT_UPDATE_USED_TABLE_IN_SF_OR_TRG = 1442
 VIEW_PREVENT_UPDATE = 1443
 PS_NO_RECURSION = 1444
 SP_CANT_SET_AUTOCOMMIT = 1445
-MALFORMED_DEFINER = 1446
 VIEW_FRM_NO_USER = 1447
 VIEW_OTHER_USER = 1448
 NO_SUCH_USER = 1449
@@ -497,7 +445,6 @@ SP_BAD_VAR_SHADOW = 1453
 TRG_NO_DEFINER = 1454
 OLD_FILE_FORMAT = 1455
 SP_RECURSION_LIMIT = 1456
-SP_PROC_TABLE_CORRUPT = 1457
 SP_WRONG_NAME = 1458
 TABLE_NEEDS_UPGRADE = 1459
 SP_NO_AGGREGATE = 1460
@@ -522,14 +469,10 @@ ILLEGAL_HA_CREATE_OPTION = 1478
 PARTITION_REQUIRES_VALUES_ERROR = 1479
 PARTITION_WRONG_VALUES_ERROR = 1480
 PARTITION_MAXVALUE_ERROR = 1481
-PARTITION_SUBPARTITION_ERROR = 1482
-PARTITION_SUBPART_MIX_ERROR = 1483
 PARTITION_WRONG_NO_PART_ERROR = 1484
 PARTITION_WRONG_NO_SUBPART_ERROR = 1485
 WRONG_EXPR_IN_PARTITION_FUNC_ERROR = 1486
-NO_CONST_EXPR_IN_RANGE_OR_LIST_ERROR = 1487
 FIELD_NOT_FOUND_PART_ERROR = 1488
-LIST_OF_FIELDS_ONLY_IN_HASH_ERROR = 1489
 INCONSISTENT_PARTITION_INFO_ERROR = 1490
 PARTITION_FUNC_NOT_ALLOWED_ERROR = 1491
 PARTITIONS_MUST_BE_DEFINED_ERROR = 1492
@@ -562,7 +505,6 @@ NO_BINLOG_ERROR = 1518
 CONSECUTIVE_REORG_PARTITIONS = 1519
 REORG_OUTSIDE_RANGE = 1520
 PARTITION_FUNCTION_FAILURE = 1521
-PART_STATE_ERROR = 1522
 LIMITED_PART_RANGE = 1523
 PLUGIN_IS_NOT_LOADED = 1524
 WRONG_VALUE = 1525
@@ -575,53 +517,30 @@ WRONG_SIZE_NUMBER = 1531
 SIZE_OVERFLOW_ERROR = 1532
 ALTER_FILEGROUP_FAILED = 1533
 BINLOG_ROW_LOGGING_FAILED = 1534
-BINLOG_ROW_WRONG_TABLE_DEF = 1535
-BINLOG_ROW_RBR_TO_SBR = 1536
 EVENT_ALREADY_EXISTS = 1537
-EVENT_STORE_FAILED = 1538
 EVENT_DOES_NOT_EXIST = 1539
-EVENT_CANT_ALTER = 1540
-EVENT_DROP_FAILED = 1541
 EVENT_INTERVAL_NOT_POSITIVE_OR_TOO_BIG = 1542
 EVENT_ENDS_BEFORE_STARTS = 1543
 EVENT_EXEC_TIME_IN_THE_PAST = 1544
-EVENT_OPEN_TABLE_FAILED = 1545
-EVENT_NEITHER_M_EXPR_NOR_M_AT = 1546
-COL_COUNT_DOESNT_MATCH_CORRUPTED = 1547
-OBSOLETE_COL_COUNT_DOESNT_MATCH_CORRUPTED = 1547
-CANNOT_LOAD_FROM_TABLE = 1548
-OBSOLETE_CANNOT_LOAD_FROM_TABLE = 1548
-EVENT_CANNOT_DELETE = 1549
-EVENT_COMPILE_ERROR = 1550
 EVENT_SAME_NAME = 1551
-EVENT_DATA_TOO_LONG = 1552
 DROP_INDEX_FK = 1553
 WARN_DEPRECATED_SYNTAX_WITH_VER = 1554
-CANT_WRITE_LOCK_LOG_TABLE = 1555
 CANT_LOCK_LOG_TABLE = 1556
-FOREIGN_DUPLICATE_KEY = 1557
 FOREIGN_DUPLICATE_KEY_OLD_UNUSED = 1557
 COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE = 1558
 TEMP_TABLE_PREVENTS_SWITCH_OUT_OF_RBR = 1559
 STORED_FUNCTION_PREVENTS_SWITCH_BINLOG_FORMAT = 1560
-NDB_CANT_SWITCH_BINLOG_FORMAT = 1561
 PARTITION_NO_TEMPORARY = 1562
 PARTITION_CONST_DOMAIN_ERROR = 1563
 PARTITION_FUNCTION_IS_NOT_ALLOWED = 1564
-DDL_LOG_ERROR = 1565
 NULL_IN_VALUES_LESS_THAN = 1566
 WRONG_PARTITION_NAME = 1567
 CANT_CHANGE_TX_CHARACTERISTICS = 1568
-CANT_CHANGE_TX_ISOLATION = 1568
 DUP_ENTRY_AUTOINCREMENT_CASE = 1569
-EVENT_MODIFY_QUEUE_ERROR = 1570
 EVENT_SET_VAR_ERROR = 1571
 PARTITION_MERGE_ERROR = 1572
-CANT_ACTIVATE_LOG = 1573
-RBR_NOT_AVAILABLE = 1574
 BASE64_DECODE_ERROR = 1575
 EVENT_RECURSION_FORBIDDEN = 1576
-EVENTS_DB_ERROR = 1577
 ONLY_INTEGERS_ALLOWED = 1578
 UNSUPORTED_LOG_ENGINE = 1579
 BAD_LOG_STATEMENT = 1580
@@ -634,41 +553,29 @@ DUP_ENTRY_WITH_KEY_NAME = 1586
 BINLOG_PURGE_EMFILE = 1587
 EVENT_CANNOT_CREATE_IN_THE_PAST = 1588
 EVENT_CANNOT_ALTER_IN_THE_PAST = 1589
-SLAVE_INCIDENT = 1590
 NO_PARTITION_FOR_GIVEN_VALUE_SILENT = 1591
 BINLOG_UNSAFE_STATEMENT = 1592
-SLAVE_FATAL_ERROR = 1593
-SLAVE_RELAY_LOG_READ_FAILURE = 1594
-SLAVE_RELAY_LOG_WRITE_FAILURE = 1595
-SLAVE_CREATE_EVENT_FAILURE = 1596
-SLAVE_MASTER_COM_FAILURE = 1597
+BINLOG_FATAL_ERROR = 1593
 BINLOG_LOGGING_IMPOSSIBLE = 1598
 VIEW_NO_CREATION_CTX = 1599
 VIEW_INVALID_CREATION_CTX = 1600
-SR_INVALID_CREATION_CTX = 1601
 TRG_CORRUPTED_FILE = 1602
 TRG_NO_CREATION_CTX = 1603
 TRG_INVALID_CREATION_CTX = 1604
 EVENT_INVALID_CREATION_CTX = 1605
 TRG_CANT_OPEN_TABLE = 1606
-CANT_CREATE_SROUTINE = 1607
-NEVER_USED = 1608
 NO_FORMAT_DESCRIPTION_EVENT_BEFORE_BINLOG_STATEMENT = 1609
 SLAVE_CORRUPT_EVENT = 1610
-LOAD_DATA_INVALID_COLUMN = 1611
 LOG_PURGE_NO_FILE = 1612
 XA_RBTIMEOUT = 1613
 XA_RBDEADLOCK = 1614
 NEED_REPREPARE = 1615
-DELAYED_NOT_SUPPORTED = 1616
 WARN_NO_MASTER_INFO = 1617
 WARN_OPTION_IGNORED = 1618
 PLUGIN_DELETE_BUILTIN = 1619
-WARN_PLUGIN_DELETE_BUILTIN = 1619
 WARN_PLUGIN_BUSY = 1620
 VARIABLE_IS_READONLY = 1621
 WARN_ENGINE_TRANSACTION_ROLLBACK = 1622
-SLAVE_HEARTBEAT_FAILURE = 1623
 SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE = 1624
 NDB_REPLICATION_SCHEMA_ERROR = 1625
 CONFLICT_FN_PARSE_ERROR = 1626
@@ -696,7 +603,6 @@ WARN_COND_ITEM_TRUNCATED = 1647
 COND_ITEM_TOO_LONG = 1648
 UNKNOWN_LOCALE = 1649
 SLAVE_IGNORE_SERVER_IDS = 1650
-QUERY_CACHE_DISABLED = 1651
 SAME_NAME_PARTITION_FIELD = 1652
 PARTITION_COLUMN_LIST_ERROR = 1653
 WRONG_TYPE_COLUMN_VALUE_ERROR = 1654
@@ -714,8 +620,6 @@ BINLOG_STMT_MODE_AND_ROW_ENGINE = 1665
 BINLOG_ROW_INJECTION_AND_STMT_MODE = 1666
 BINLOG_MULTIPLE_ENGINES_AND_SELF_LOGGING_ENGINE = 1667
 BINLOG_UNSAFE_LIMIT = 1668
-BINLOG_UNSAFE_INSERT_DELAYED = 1669
-UNUSED4 = 1669
 BINLOG_UNSAFE_SYSTEM_TABLE = 1670
 BINLOG_UNSAFE_AUTOINC_COLUMNS = 1671
 BINLOG_UNSAFE_UDF = 1672
@@ -723,7 +627,6 @@ BINLOG_UNSAFE_SYSTEM_VARIABLE = 1673
 BINLOG_UNSAFE_SYSTEM_FUNCTION = 1674
 BINLOG_UNSAFE_NONTRANS_AFTER_TRANS = 1675
 MESSAGE_AND_STATEMENT = 1676
-SLAVE_CONVERSION_FAILED = 1677
 SLAVE_CANT_CREATE_CONVERSION = 1678
 INSIDE_TRANSACTION_PREVENTS_SWITCH_BINLOG_FORMAT = 1679
 PATH_LENGTH = 1680
@@ -746,7 +649,6 @@ FAILED_READ_FROM_PAR_FILE = 1696
 VALUES_IS_NOT_INT_TYPE_ERROR = 1697
 ACCESS_DENIED_NO_PASSWORD_ERROR = 1698
 SET_PASSWORD_AUTH_PLUGIN = 1699
-GRANT_PLUGIN_USER_EXISTS = 1700
 TRUNCATE_ILLEGAL_FK = 1701
 PLUGIN_IS_PERMANENT = 1702
 SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE_MIN = 1703
@@ -773,10 +675,8 @@ BINLOG_UNSAFE_CREATE_SELECT_AUTOINC = 1723
 BINLOG_UNSAFE_INSERT_TWO_KEYS = 1724
 TABLE_IN_FK_CHECK = 1725
 UNSUPPORTED_ENGINE = 1726
-UNUSED_1 = 1726
 BINLOG_UNSAFE_AUTOINC_NOT_FIRST = 1727
 CANNOT_LOAD_FROM_TABLE_V2 = 1728
-LAST_MYSQL_ERROR_MESSAGE = 1728
 MASTER_DELAY_VALUE_OUT_OF_RANGE = 1729
 ONLY_FD_AND_RBR_EVENTS_ALLOWED_IN_BINLOG_STATEMENT = 1730
 PARTITION_EXCHANGE_DIFFERENT_OPTION = 1731
@@ -789,15 +689,11 @@ ROW_DOES_NOT_MATCH_PARTITION = 1737
 BINLOG_CACHE_SIZE_GREATER_THAN_MAX = 1738
 WARN_INDEX_NOT_APPLICABLE = 1739
 PARTITION_EXCHANGE_FOREIGN_KEY = 1740
-NO_SUCH_KEY_VALUE = 1741
 RPL_INFO_DATA_TOO_LONG = 1742
-NETWORK_READ_EVENT_CHECKSUM_FAILURE = 1743
-BINLOG_READ_EVENT_CHECKSUM_FAILURE = 1744
 BINLOG_STMT_CACHE_SIZE_GREATER_THAN_MAX = 1745
 CANT_UPDATE_TABLE_IN_CREATE_TABLE_SELECT = 1746
 PARTITION_CLAUSE_ON_NONPARTITIONED = 1747
 ROW_DOES_NOT_MATCH_GIVEN_PARTITION_SET = 1748
-NO_SUCH_PARTITION__UNUSED = 1749
 CHANGE_RPL_INFO_REPOSITORY_FAILURE = 1750
 WARNING_NOT_COMPLETE_ROLLBACK_WITH_CREATED_TEMP_TABLE = 1751
 WARNING_NOT_COMPLETE_ROLLBACK_WITH_DROPPED_TEMP_TABLE = 1752
@@ -815,24 +711,19 @@ SQLTHREAD_WITH_SECURE_SLAVE = 1763
 TABLE_HAS_NO_FT = 1764
 VARIABLE_NOT_SETTABLE_IN_SF_OR_TRIGGER = 1765
 VARIABLE_NOT_SETTABLE_IN_TRANSACTION = 1766
-GTID_NEXT_IS_NOT_IN_GTID_NEXT_LIST = 1767
-CANT_CHANGE_GTID_NEXT_IN_TRANSACTION_WHEN_GTID_NEXT_LIST_IS_NULL = 1768
 SET_STATEMENT_CANNOT_INVOKE_FUNCTION = 1769
 GTID_NEXT_CANT_BE_AUTOMATIC_IF_GTID_NEXT_LIST_IS_NON_NULL = 1770
-SKIPPING_LOGGED_TRANSACTION = 1771
 MALFORMED_GTID_SET_SPECIFICATION = 1772
 MALFORMED_GTID_SET_ENCODING = 1773
 MALFORMED_GTID_SPECIFICATION = 1774
 GNO_EXHAUSTED = 1775
 BAD_SLAVE_AUTO_POSITION = 1776
-AUTO_POSITION_REQUIRES_GTID_MODE_ON = 1777
+AUTO_POSITION_REQUIRES_GTID_MODE_NOT_OFF = 1777
 CANT_DO_IMPLICIT_COMMIT_IN_TRX_WHEN_GTID_NEXT_IS_SET = 1778
-GTID_MODE_2_OR_3_REQUIRES_ENFORCE_GTID_CONSISTENCY_ON = 1779
-GTID_MODE_REQUIRES_BINLOG = 1780
+GTID_MODE_ON_REQUIRES_ENFORCE_GTID_CONSISTENCY_ON = 1779
 CANT_SET_GTID_NEXT_TO_GTID_WHEN_GTID_MODE_IS_OFF = 1781
 CANT_SET_GTID_NEXT_TO_ANONYMOUS_WHEN_GTID_MODE_IS_ON = 1782
 CANT_SET_GTID_NEXT_LIST_TO_NON_NULL_WHEN_GTID_MODE_IS_OFF = 1783
-FOUND_GTID_EVENT_WHEN_GTID_MODE_IS_OFF = 1784
 GTID_UNSAFE_NON_TRANSACTIONAL_TABLE = 1785
 GTID_UNSAFE_CREATE_SELECT = 1786
 GTID_UNSAFE_CREATE_DROP_TEMPORARY_TABLE_IN_TRANSACTION = 1787
@@ -882,12 +773,10 @@ FK_COLUMN_NOT_NULL = 1830
 DUP_INDEX = 1831
 FK_COLUMN_CANNOT_CHANGE = 1832
 FK_COLUMN_CANNOT_CHANGE_CHILD = 1833
-UNUSED5 = 1834
 MALFORMED_PACKET = 1835
 READ_ONLY_MODE = 1836
-GTID_NEXT_TYPE_UNDEFINED_GROUP = 1837
+GTID_NEXT_TYPE_UNDEFINED_GTID = 1837
 VARIABLE_NOT_SETTABLE_IN_SP = 1838
-CANT_SET_GTID_PURGED_WHEN_GTID_MODE_IS_OFF = 1839
 CANT_SET_GTID_PURGED_WHEN_GTID_EXECUTED_IS_NOT_EMPTY = 1840
 CANT_SET_GTID_PURGED_WHEN_OWNED_GTIDS_IS_NOT_EMPTY = 1841
 GTID_PURGED_WAS_CHANGED = 1842
@@ -900,7 +789,6 @@ ALTER_OPERATION_NOT_SUPPORTED_REASON_PARTITION = 1848
 ALTER_OPERATION_NOT_SUPPORTED_REASON_FK_RENAME = 1849
 ALTER_OPERATION_NOT_SUPPORTED_REASON_COLUMN_TYPE = 1850
 ALTER_OPERATION_NOT_SUPPORTED_REASON_FK_CHECK = 1851
-UNUSED6 = 1852
 ALTER_OPERATION_NOT_SUPPORTED_REASON_NOPK = 1853
 ALTER_OPERATION_NOT_SUPPORTED_REASON_AUTOINC = 1854
 ALTER_OPERATION_NOT_SUPPORTED_REASON_HIDDEN_FTS = 1855
@@ -913,7 +801,6 @@ ALTER_OPERATION_NOT_SUPPORTED_REASON_NOT_NULL = 1861
 MUST_CHANGE_PASSWORD_LOGIN = 1862
 ROW_IN_WRONG_PARTITION = 1863
 MTS_EVENT_BIGGER_PENDING_JOBS_SIZE_MAX = 1864
-INNODB_NO_FT_USES_PARSER = 1865
 BINLOG_LOGICAL_CORRUPTION = 1866
 WARN_PURGE_LOG_IN_USE = 1867
 WARN_PURGE_LOG_IS_ACTIVE = 1868
@@ -932,129 +819,7 @@ OLD_TEMPORALS_UPGRADED = 1880
 INNODB_FORCED_RECOVERY = 1881
 AES_INVALID_IV = 1882
 PLUGIN_CANNOT_BE_UNINSTALLED = 1883
-GTID_UNSAFE_BINLOG_SPLITTABLE_STATEMENT_AND_GTID_GROUP = 1884
-FILE_CORRUPT = 1885
-ERROR_ON_MASTER = 1886
-INCONSISTENT_ERROR = 1887
-STORAGE_ENGINE_NOT_LOADED = 1888
-GET_STACKED_DA_WITHOUT_ACTIVE_HANDLER = 1889
-WARN_LEGACY_SYNTAX_CONVERTED = 1890
-BINLOG_UNSAFE_FULLTEXT_PLUGIN = 1891
-CANNOT_DISCARD_TEMPORARY_TABLE = 1892
-FK_DEPTH_EXCEEDED = 1893
-COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE_V2 = 1894
-WARN_TRIGGER_DOESNT_HAVE_CREATED = 1895
-REFERENCED_TRG_DOES_NOT_EXIST = 1896
-EXPLAIN_NOT_SUPPORTED = 1897
-INVALID_FIELD_SIZE = 1898
-MISSING_HA_CREATE_OPTION = 1899
-ENGINE_OUT_OF_MEMORY = 1900
-VCOL_BASED_ON_VCOL = 1900
-PASSWORD_EXPIRE_ANONYMOUS_USER = 1901
-VIRTUAL_COLUMN_FUNCTION_IS_NOT_ALLOWED = 1901
-DATA_CONVERSION_ERROR_FOR_VIRTUAL_COLUMN = 1902
-SLAVE_SQL_THREAD_MUST_STOP = 1902
-NO_FT_MATERIALIZED_SUBQUERY = 1903
-PRIMARY_KEY_BASED_ON_VIRTUAL_COLUMN = 1903
-INNODB_UNDO_LOG_FULL = 1904
-KEY_BASED_ON_GENERATED_VIRTUAL_COLUMN = 1904
-INVALID_ARGUMENT_FOR_LOGARITHM = 1905
-WRONG_FK_OPTION_FOR_VIRTUAL_COLUMN = 1905
-SLAVE_CHANNEL_IO_THREAD_MUST_STOP = 1906
-WARNING_NON_DEFAULT_VALUE_FOR_VIRTUAL_COLUMN = 1906
-UNSUPPORTED_ACTION_ON_VIRTUAL_COLUMN = 1907
-WARN_OPEN_TEMP_TABLES_MUST_BE_ZERO = 1907
-CONST_EXPR_IN_VCOL = 1908
-WARN_ONLY_MASTER_LOG_FILE_NO_POS = 1908
-QUERY_TIMEOUT = 1909
-ROW_EXPR_FOR_VCOL = 1909
-NON_RO_SELECT_DISABLE_TIMER = 1910
-UNSUPPORTED_ENGINE_FOR_VIRTUAL_COLUMNS = 1910
-DUP_LIST_ENTRY = 1911
-UNKNOWN_OPTION = 1911
-BAD_OPTION_VALUE = 1912
-SQL_MODE_NO_EFFECT = 1912
-AGGREGATE_ORDER_FOR_UNION = 1913
-NETWORK_READ_EVENT_CHECKSUM_FAILURE = 1913
-AGGREGATE_ORDER_NON_AGG_QUERY = 1914
-BINLOG_READ_EVENT_CHECKSUM_FAILURE = 1914
-CANT_DO_ONLINE = 1915
-SLAVE_WORKER_STOPPED_PREVIOUS_THD_ERROR = 1915
-DATA_OVERFLOW = 1916
-DONT_SUPPORT_SLAVE_PRESERVE_COMMIT_ORDER = 1916
-DATA_TRUNCATED = 1917
-SERVER_OFFLINE_MODE = 1917
-BAD_DATA = 1918
-GIS_DIFFERENT_SRIDS = 1918
-DYN_COL_WRONG_FORMAT = 1919
-GIS_UNSUPPORTED_ARGUMENT = 1919
-DYN_COL_IMPLEMENTATION_LIMIT = 1920
-GIS_UNKNOWN_ERROR = 1920
-DYN_COL_DATA = 1921
-GIS_UNKNOWN_EXCEPTION = 1921
-DYN_COL_WRONG_CHARSET = 1922
-GIS_INVALID_DATA = 1922
-BOOST_GEOMETRY_EMPTY_INPUT_EXCEPTION = 1923
-ILLEGAL_SUBQUERY_OPTIMIZER_SWITCHES = 1923
-BOOST_GEOMETRY_CENTROID_EXCEPTION = 1924
-QUERY_CACHE_IS_DISABLED = 1924
-BOOST_GEOMETRY_OVERLAY_INVALID_INPUT_EXCEPTION = 1925
-QUERY_CACHE_IS_GLOBALY_DISABLED = 1925
-BOOST_GEOMETRY_TURN_INFO_EXCEPTION = 1926
-VIEW_ORDERBY_IGNORED = 1926
-BOOST_GEOMETRY_SELF_INTERSECTION_POINT_EXCEPTION = 1927
-CONNECTION_KILLED = 1927
-BOOST_GEOMETRY_UNKNOWN_EXCEPTION = 1928
-INTERNAL_ERROR = 1928
-INSIDE_TRANSACTION_PREVENTS_SWITCH_SKIP_REPLICATION = 1929
-STD_BAD_ALLOC_ERROR = 1929
-STD_DOMAIN_ERROR = 1930
-STORED_FUNCTION_PREVENTS_SWITCH_SKIP_REPLICATION = 1930
-QUERY_EXCEEDED_ROWS_EXAMINED_LIMIT = 1931
-STD_LENGTH_ERROR = 1931
-NO_SUCH_TABLE_IN_ENGINE = 1932
-STD_INVALID_ARGUMENT = 1932
-GEOMETRY_SRID_MISMATCH = 1933
-STD_OUT_OF_RANGE_ERROR = 1933
-NO_SUCH_SPATIAL_REF_ID = 1934
-STD_OVERFLOW_ERROR = 1934
-STD_RANGE_ERROR = 1935
-STD_UNDERFLOW_ERROR = 1936
-STD_LOGIC_ERROR = 1937
-STD_RUNTIME_ERROR = 1938
-STD_UNKNOWN_EXCEPTION = 1939
-GIS_DATA_WRONG_ENDIANESS = 1940
-CHANGE_MASTER_PASSWORD_LENGTH = 1941
-USER_LOCK_WRONG_NAME = 1942
-USER_LOCK_DEADLOCK = 1943
-REPLACE_INACCESSIBLE_ROWS = 1944
-ALTER_OPERATION_NOT_SUPPORTED_REASON_GIS = 1945
-ILLEGAL_USER_VAR = 1946
-GTID_MODE_OFF = 1947
-UNSUPPORTED_BY_REPLICATION_THREAD = 1948
-INCORRECT_TYPE = 1949
-FIELD_IN_ORDER_NOT_SELECT = 1950
-AGGREGATE_IN_ORDER_NOT_SELECT = 1951
-INVALID_RPL_WILD_TABLE_FILTER_PATTERN = 1952
-NET_OK_PACKET_TOO_LARGE = 1953
-INVALID_JSON_DATA = 1954
-INVALID_GEOJSON_MISSING_MEMBER = 1955
-INVALID_GEOJSON_WRONG_TYPE = 1956
-INVALID_GEOJSON_UNSPECIFIED = 1957
-DIMENSION_UNSUPPORTED = 1958
-SLAVE_CHANNEL_DOES_NOT_EXIST = 1959
-SLAVE_MULTIPLE_CHANNELS_HOST_PORT = 1960
-SLAVE_CHANNEL_NAME_INVALID_OR_TOO_LONG = 1961
-SLAVE_NEW_CHANNEL_WRONG_REPOSITORY = 1962
-SLAVE_CHANNEL_DELETE = 1963
-SLAVE_MULTIPLE_CHANNELS_CMD = 1964
-SLAVE_MAX_CHANNELS_EXCEEDED = 1965
-SLAVE_CHANNEL_MUST_STOP = 1966
-SLAVE_CHANNEL_NOT_RUNNING = 1967
-SLAVE_CHANNEL_WAS_RUNNING = 1968
-SLAVE_CHANNEL_WAS_NOT_RUNNING = 1969
-SLAVE_CHANNEL_SQL_THREAD_MUST_STOP = 1970
-SLAVE_CHANNEL_SQL_SKIP_COUNTER = 1971
-WRONG_FIELD_WITH_GROUP_V2 = 1972
-MIX_OF_GROUP_FUNC_AND_FIELDS_V2 = 1973
+GTID_UNSAFE_BINLOG_SPLITTABLE_STATEMENT_AND_ASSIGNED_GTID = 1884
+SLAVE_HAS_MORE_GTIDS_THAN_MASTER = 1885
+MISSING_KEY = 1886
 ERROR_LAST = 1973
